@@ -19,7 +19,7 @@ describe ApolloUploadServer::Middleware do
 
     context "when CONTENT_TYPE is 'multipart/form-data'" do
       subject do
-        Rack::MockRequest.new(app).post('/', { 'CONTENT_TYPE' => 'multipart/form-data', input: 'operations=foo&map=bar' })
+        Rack::MockRequest.new(app).post('/', { 'CONTENT_TYPE' => 'multipart/form-data', input: 'operations={}&map={}' })
       end
 
       it { expect(subject.status).to eq(200) }
@@ -39,10 +39,12 @@ describe ApolloUploadServer::Middleware do
       end
 
       subject do
-        Rack::MockRequest.new(app).post('/', { 'CONTENT_TYPE' => 'multipart/form-data', input: 'operations=foo&map=bar' })
+        Rack::MockRequest.new(app).post('/', { 'CONTENT_TYPE' => 'multipart/form-data', input: 'operations={}&map={}' })
       end
 
       it 'propagates this setting to the data builder' do
+        expect(ApolloUploadServer::GraphQLDataBuilder).to receive(:new).with(strict_mode: true).and_call_original
+
         subject
       end
     end
